@@ -84,6 +84,14 @@ def pop_keys(keys_list, keys_to_pop):
     return keys_remainded_list
 
 
+def fmt_size(num, suffix="B"):
+    for unit in ["", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi"]:
+        if abs(num) < 1024.0:
+            return "%3.1f%s%s" % (num, unit, suffix)
+        num /= 1024.0
+    return "%.1f%s%s" % (num, "Yi", suffix)
+
+
 ################################################################################
 ## list
 ################################################################################
